function [D0_C,D0_L,D0_R] = compute_distances(X3D,Y3D,Z3D,varargin)

if nargin < 4 || isempty(varargin{1})
    mode = 1; else mode = varargin{1}; end

% compute distances between neighbouring points along R,L,C directions

switch mode
    case 1
        % -- circumferential
        X3D_circ = cat(2,X3D(:,end,:),X3D,X3D(:,1,:));
        Y3D_circ = cat(2,Y3D(:,end,:),Y3D,Y3D(:,1,:));
        Z3D_circ = cat(2,Z3D(:,end,:),Z3D,Z3D(:,1,:));
        
        D0_Cb = sqrt( (X3D_circ(:,2:end-1,:) - X3D_circ(:,1:end-2,:)).^2 + ... % backwards
            (Y3D_circ(:,2:end-1,:) - Y3D_circ(:,1:end-2,:)).^2 + ...
            (Z3D_circ(:,2:end-1,:) - Z3D_circ(:,1:end-2,:)).^2 );
        
        D0_Cf = sqrt( (X3D_circ(:,2:end-1,:) - X3D_circ(:,3:end,:)).^2 + ... % forward
            (Y3D_circ(:,2:end-1,:) - Y3D_circ(:,3:end,:)).^2 + ...
            (Z3D_circ(:,2:end-1,:) - Z3D_circ(:,3:end,:)).^2 );
        
        % -- longitudinal
        D0_Lb = sqrt( (X3D(2:end,:,:) - X3D(1:end-1,:,:).^2) + ... % backwards
            (Y3D(2:end,:,:) - Y3D(1:end-1,:,:).^2) + ...
            (Z3D(2:end,:,:) - Z3D(1:end-1,:,:).^2) );
        
        D0_Lf = sqrt( (X3D(1:end-1,:,:) - X3D(2:end,:,:).^2) + ... % forward
            (Y3D(1:end-1,:,:) - Y3D(2:end,:,:).^2) + ...
            (Z3D(1:end-1,:,:) - Z3D(2:end,:,:).^2) );
        
        % -- radial
        D0_Rb = sqrt( (X3D(:,:,2:end) - X3D(:,:,1:end-1)).^2 + ... % b
            (Y3D(:,:,2:end) - Y3D(:,:,1:end-1)).^2 + ...
            (Z3D(:,:,2:end) - Z3D(:,:,1:end-1)).^2 );
        
        D0_Rf = sqrt( (X3D(:,:,1:end-1) - X3D(:,:,2:end)).^2 + ... % b
            (Y3D(:,:,1:end-1) - Y3D(:,:,2:end)).^2 + ...
            (Z3D(:,:,1:end-1) - Z3D(:,:,2:end)).^2 );
        
        % center
        D0_C = .5 * (D0_Cb + D0_Cf);
        D0_L = cat(1,D0_Lf(1,:,:),.5*(D0_Lf(2:end,:,:) + D0_Lb(1:end-1,:,:)) ,D0_Lb(end,:,:));
        D0_R = cat(3,D0_Rf(:,:,1),.5*(D0_Rf(:,:,2:end) + D0_Rb(:,:,1:end-1)) ,D0_Rb(:,:,end));
        
    case 2
        
        D0_C = nan(size(X3D));
        D0_L = D0_C;
        D0_R = D0_C;
        
        X3D_circ = cat(2,X3D,X3D(:,1,:));
        Y3D_circ = cat(2,Y3D,Y3D(:,1,:));
        Z3D_circ = cat(2,Z3D,Z3D(:,1,:));
        
        D0_C = sqrt( diff(X3D_circ,1,2).^2 + diff(Y3D_circ,1,2).^2 + diff(Z3D_circ,1,2).^2);
        D0_L(1:end-1,:,:) = sqrt( diff(X3D,1,1).^2 + diff(Y3D,1,1).^2 + diff(Z3D,1,1).^2);
        D0_R(:,:,1:end-1) = sqrt( diff(X3D,1,3).^2 + diff(Y3D,1,3).^2 + diff(Z3D,1,3).^2);
        
end