function write_vtkMesh(filename, mesh)
% Function for writing a mesh in a Visualization Toolkit (VTK) format
% 
% mesh  = write_vtkMesh(filename);
%
% examples:
%   mesh=write_vtkMesh('volume.vtk');
%   mesh would be of the class MeshType

fid=fopen(filename,'wb');
if(fid<0)
    fprintf('could not open file %s for writing\n',filename);
    return
end

% write header
dlmwrite(filename, ['# vtk DataFile Version 3.0'],'delimiter','');
dlmwrite(filename, ['vtk output'],'delimiter','','-append');
dlmwrite(filename, ['ASCII'],'delimiter','','-append');
dlmwrite(filename, ['DATASET UNSTRUCTURED_GRID'],'delimiter','','-append');

% write points
dlmwrite(filename, ['POINTS ' num2str(mesh.npoints) ' float' ],'delimiter','','-append');
dlmwrite(filename, mesh.points,'delimiter',' ','-append');

%write triangles
dlmwrite(filename, ['CELLS ' num2str(mesh.ntriangles) ' ' num2str((size(mesh.triangles,2)+1)*mesh.ntriangles)  ],'delimiter','','-append');
dlmwrite(filename, [ones(mesh.ntriangles,1)*size(mesh.triangles,2) mesh.triangles-1] ,'delimiter',' ','-append');

% write cell types
dlmwrite(filename, ['CELL_TYPES ' num2str(mesh.ntriangles)],'delimiter','','-append');
dlmwrite(filename, [10*ones(mesh.ntriangles,1)] ,'delimiter',' ','-append');

% write attributes
nattributes = numel(mesh.attributes);
nfielddatas = 0;

% count fieldData



if (nattributes>0)
%if (0)
    dlmwrite(filename, [' '],'delimiter','','-append');
    dlmwrite(filename, ['POINT_DATA ' num2str(mesh.attributes(1).nelements) ],'delimiter','','-append');
    for j=1:nattributes
        if ~numel(lower(mesh.attributes(j).attribute))
            continue;
        end
        switch (lower(mesh.attributes(j).attribute))
            case 'scalars'
                dlmwrite(filename, [upper(mesh.attributes(j).attribute) ' ' mesh.attributes(j).name ' ' mesh.attributes(j).type ],'delimiter','','-append');
                dlmwrite(filename, [ 'LOOKUP_TABLE ' mesh.attributes(j).lookup_table ],'delimiter','','-append');
                dlmwrite(filename, mesh.attributes(j).attribute_array ,'delimiter','','-append');
            
            case 'field'
                nfielddatas = nfielddatas+1;
                dlmwrite(filename, ['FIELD FieldData ' num2str(nfielddatas)  ],'delimiter','','-append');
                dlmwrite(filename, [ mesh.attributes(j).name ' ' num2str(mesh.attributes(j).numComp) ' ' num2str(mesh.attributes(j).nelements) ' ' mesh.attributes(j).type ],'delimiter','','-append');
                dlmwrite(filename, mesh.attributes(j).attribute_array ,'delimiter',' ','-append');
            
            case 'vectors'
                 nfielddatas = nfielddatas+1;
                 %dlmwrite(filename, [ upper(mesh.attributes(j).attribute) ' FieldData ' num2str(nfielddatas) ],'delimiter','','-append');
                 dlmwrite(filename, [ upper(mesh.attributes(j).attribute) '  ' mesh.attributes(j).name   ' ' mesh.attributes(j).type ],'delimiter','','-append');
                 dlmwrite(filename, mesh.attributes(j).attribute_array ,'delimiter',' ','-append');
            
            otherwise
                % do nothing
        end
    end
end