function write_vtkMesh_martino(filename, mesh)
% Function for writing a mesh in a Visualization Toolkit (VTK) format
% 
% mesh  = write_vtkMesh(filename);
%
% examples:
%   mesh=write_vtkMesh('volume.vtk');
%   mesh would be of the class MeshType

fid=fopen(filename,'wb');
if(fid<0)
    fprintf('could not open file %s for writing\n',filename);
    return
end

% write header
dlmwrite(filename, ['# vtk DataFile Version 3.0'],'delimiter','');
dlmwrite(filename, ['vtk output'],'delimiter','','-append');
dlmwrite(filename, ['ASCII'],'delimiter','','-append');
dlmwrite(filename, ['DATASET UNSTRUCTURED_GRID'],'delimiter','','-append');

% write points
dlmwrite(filename, ['POINTS ' num2str(mesh.npoints) ' float' ],'delimiter','','-append');
dlmwrite(filename, mesh.points,'delimiter',' ','-append');

%write triangles
dlmwrite(filename, ['CELLS ' num2str(mesh.ntriangles) ' ' num2str((size(mesh.triangles,2)+1)*mesh.ntriangles)  ],'delimiter','','-append');
dlmwrite(filename, [ones(mesh.ntriangles,1)*size(mesh.triangles,2) mesh.triangles-1] ,'delimiter',' ','-append');

% write cell types
dlmwrite(filename, ['CELL_TYPES ' num2str(mesh.ntriangles)],'delimiter','','-append');
dlmwrite(filename, [10*ones(mesh.ntriangles,1)] ,'delimiter',' ','-append');

% write attributes
nattributes = numel(mesh.attributes);

idx_point = [];
idx_cell = [];

if (nattributes>0)
    for j=1:nattributes
        if mesh.attributes(j).nelements == mesh.ntriangles % cell data
            idx_cell = [idx_cell j];
        elseif mesh.attributes(j).nelements == mesh.npoints % point data
            idx_point = [idx_point j];
        end
    end
end
    
%%% write cell data
if numel(idx_cell)>0

    dlmwrite(filename, [' '],'delimiter','','-append');
    dlmwrite(filename, ['CELL_DATA ' num2str(mesh.attributes(idx_cell(1)).nelements)],'delimiter','','-append');
    dlmwrite(filename, ['FIELD FieldData ' num2str(numel(idx_cell))],'delimiter','','-append'); 
    for j=1:numel(idx_cell) 
         dlmwrite(filename, [mesh.attributes(idx_cell(j)).name ' ' num2str(mesh.attributes(idx_cell(j)).numComp) ' ' num2str(mesh.attributes(idx_cell(j)).nelements) ' ' mesh.attributes(idx_cell(j)).type ],'delimiter','','-append');
         dlmwrite(filename, mesh.attributes(idx_cell(j)).attribute_array ,'delimiter',' ','-append');  
    end
    debug();
    
end

%%% write point data
if numel(idx_point)>0

    dlmwrite(filename, [' '],'delimiter','','-append');
    dlmwrite(filename, ['POINT_DATA ' num2str(mesh.attributes(idx_point(1)).nelements)],'delimiter','','-append');
    dlmwrite(filename, ['FIELD FieldData ' num2str(numel(idx_point))],'delimiter','','-append'); 
    for j=1:numel(idx_point) 
         dlmwrite(filename, [mesh.attributes(idx_point(j)).name ' ' num2str(mesh.attributes(idx_point(j)).numComp) ' ' num2str(mesh.attributes(idx_point(j)).nelements) ' ' mesh.attributes(idx_point(j)).type ],'delimiter','','-append');
         dlmwrite(filename, mesh.attributes(idx_point(j)).attribute_array ,'delimiter',' ','-append');  
    end
    debug();
    
end
fclose(fid);


% if (nattributes>0)
%     
%     % point data
%     dlmwrite(filename, [' '],'delimiter','','-append');
%     dlmwrite(filename, ['POINT_DATA ' num2str(mesh.attributes(1).nelements) ],'delimiter','','-append');
%     
%     % count point data
%     nfielddatas = 0;
%     idx_field = [];
%     for j=1:nattributes
%         switch (lower(mesh.attributes(j).attribute))          
%             case 'field'
%                 nfielddatas = nfielddatas+1;
%                 idx_field = [idx_field j];        
%         end
%     end
% 
%     if nfielddatas > 0
%        dlmwrite(filename, ['FIELD FieldData ' num2str(nfielddatas)  ],'delimiter','','-append'); 
%        for j=1:nfielddatas 
%           dlmwrite(filename, [mesh.attributes(idx_field(j)).name ' ' num2str(mesh.attributes(idx_field(j)).numComp) ' ' num2str(mesh.attributes(idx_field(j)).nelements) ' ' mesh.attributes(idx_field(j)).type ],'delimiter','','-append');
%           dlmwrite(filename, mesh.attributes(idx_field(j)).attribute_array ,'delimiter',' ','-append');  
%        end
%     end
% end
%     for j=1:nattributes
%         if ~numel(lower(mesh.attributes(j).attribute))
%             continue;
%         end
%         switch (lower(mesh.attributes(j).attribute))
%             case 'scalars'
%                 dlmwrite(filename, [upper(mesh.attributes(j).attribute) ' ' mesh.attributes(j).name ' ' mesh.attributes(j).type ],'delimiter','','-append');
%                 dlmwrite(filename, [ 'LOOKUP_TABLE ' mesh.attributes(j).lookup_table ],'delimiter','','-append');
%                 dlmwrite(filename, mesh.attributes(j).attribute_array ,'delimiter','','-append');
%             
%             case 'field'
%                 nfielddatas = nfielddatas+1;
%                 
%                 
%             
%             case 'vectors'
%                  nfielddatas = nfielddatas+1;
%                  %dlmwrite(filename, [ upper(mesh.attributes(j).attribute) ' FieldData ' num2str(nfielddatas) ],'delimiter','','-append');
%                  dlmwrite(filename, [ upper(mesh.attributes(j).attribute) '  ' mesh.attributes(j).name   ' ' mesh.attributes(j).type ],'delimiter','','-append');
%                  dlmwrite(filename, mesh.attributes(j).attribute_array ,'delimiter',' ','-append');
%             
%             otherwise
%                 % do nothing
%         end
%     end
    
