function write_vtk_mesh_fields(savename,face,nodes,)

% convert the mesh defined by [points,triangles] to vtk format
% x y z are the nodes coordinates
% face is the triangulation matrix

fid = fopen(savename, 'w');
fprintf(fid,'# vtk DataFile Version 3.0\n');
fprintf(fid,'vtk output\n');
fprintf(fid,'ASCII\n');
fprintf(fid,'DATASET UNSTRUCTURED_GRID\n');
fprintf(fid,['POINTS ' num2str(numel(x)) ' float\n']);
numpoints = numel(x);
rem = mod(numpoints,3);
n_full_lines = floor(numpoints/3);

% writing vertexes

for jj = 1:n_full_lines
    id = (jj-1)*3+1;
    vec = [y(id) x(id) z(id) ...
        y(id+1) x(id+1) z(id+1) ...
        y(id+2) x(id+2) z(id+2)];
    fprintf(fid, '%g %g %g %g %g %g %g %g %g\n', vec);
    debug();
end

if rem > 0
    vec = [];
    form = [];
    id = id + 2;
    for jj = 1:rem
        vec = [vec y(id+jj) x(id+jj) z(id+jj)];
        form = horzcat(form,'%g %g %g ');
    end
    fprintf(fid,[form '\n'], vec);
end

clear x y z
nfaces = size(face,2);
ntriangles = size(face,1);

% writing faces
fprintf(fid, ['CELLS ' num2str(ntriangles) ' ' num2str((nfaces+1)*ntriangles) '\n']);
B = face;


B = [nfaces*ones(ntriangles,1) B];
switch size(B,2)
    case 4
        fprintf(fid, '%g %g %g %g\n', B');
    case 5
        fprintf(fid, '%g %g %g %g %g\n', B');
    case 9 
        fprintf(fid, '%g %g %g %g %g %g %g %g %g\n', B');
end
fprintf(fid, ['\n']);
fprintf(fid, ['\n']);
fprintf(fid, ['CELL_TYPES ' num2str(ntriangles) '\n']);
B = 10*ones([1 ntriangles]);
fprintf(fid, '%g \n', B);
fclose(fid);